@@ -54,6 +54,79 @@ def send_event_to_bundle(event_type: int, event: int, bundle: str):
 
     new_event.sendEventWithOptions_timeout_error_(kAEWaitReply|kAECanInteract, kAEDefaultTimeout, None)
 
+KEYCODES = {
+    "a": 0x00,
+    "s": 0x01,
+    "d": 0x02,
+    "f": 0x03,
+    "h": 0x04,
+    "g": 0x05,
+    "z": 0x06,
+    "x": 0x07,
+    "c": 0x08,
+    "v": 0x09,
+    "b": 0x0B,
+    "q": 0x0C,
+    "w": 0x0D,
+    "e": 0x0E,
+    "r": 0x0F,
+    "y": 0x10,
+    "t": 0x11,
+    "1": 0x12,
+    "2": 0x13,
+    "3": 0x14,
+    "4": 0x15,
+    "6": 0x16,
+    "5": 0x17,
+    "=": 0x18,
+    "9": 0x19,
+    "7": 0x1A,
+    "-": 0x1B,
+    "8": 0x1C,
+    "0": 0x1D,
+    "]": 0x1E,
+    "o": 0x1F,
+    "u": 0x20,
+    "[": 0x21,
+    "i": 0x22,
+    "p": 0x23,
+    "l": 0x25,
+    "j": 0x26,
+    "'": 0x27,
+    "k": 0x28,
+    ";": 0x29,
+    "\\": 0x2A,
+    ",": 0x2B,
+    "/": 0x2C,
+    "n": 0x2D,
+    "m": 0x2E,
+    "." : 0x2F,
+    " ": 0x31,
+    "`": 0x32,
+
+    "!": 0x12,
+    "@": 0x13,
+    "#": 0x14,
+    "$": 0x15,
+    "^": 0x16,
+    "%": 0x17,
+    "+": 0x18,
+    "(": 0x19,
+    "&": 0x1A,
+    "_": 0x1B,
+    "*": 0x1C,
+    ")": 0x1D,
+    "}": 0x1E,
+    "{": 0x21,
+    '"': 0x27,
+    ":": 0x29,
+    "|": 0x2A,
+    "<": 0x2B,
+    "?": 0x2C,
+    ">" : 0x2F,
+    "~": 0x32,
+}
+
 kAENoReply            =  1
 kAENeverInteract      = 16
 kAEDefaultTimeout     = -1
@@ -1029,8 +1102,8 @@ def event_from_str(s: str) -> ApplicationServices.NSAppleEventDescriptor:
     """
     return ApplicationServices.NSAppleEventDescriptor.descriptorWithString_(s)
 
-def event_from_type_code(s: str):
-    return ApplicationServices.NSAppleEventDescriptor.descriptorWithTypeCode_(s)
+def event_from_type_code(code: int):
+    return ApplicationServices.NSAppleEventDescriptor.descriptorWithTypeCode_(code)
 
 
 def event_from_bool(b: bool) -> ApplicationServices.NSAppleEventDescriptor:
