@@ -1,8 +1,5 @@
 from .PyXA import (
-    application, Application,
-    current_application,
-    running_applications,
-    supported_applications,
+    application,
 )
 
 from .XABase import (
@@ -15,21 +12,15 @@ from .XABase import (
     XAImage,
     XAVideo,
     XALocation,
+    Application,
 
     # Utilities
-    XAPredicate,
-    SDEFParser,
-
-    # Interoperability
     AppleScript,
+    XAPredicate,
     
     # System Features
     XAClipboard,
     XASpotlight,
-    XACommandDetector,
-    XASpeechRecognizer,
-    XASpeech,
-    XALSM,
 
     # Alerts, Dialogs, Menus, and Notifications
     XAAlert, XAAlertStyle,
@@ -37,9 +28,32 @@ from .XABase import (
     XADialog, XAFileNameDialog,
     XAColorPicker, XAColorPickerStyle,
     XANotification,
-    XAMenuBar, XAMenu,
+    XAMenu,
+
+    # Constants
+    VERSION,
+
+    # XAFinderExtension,
+
+    # Methods
+    current_application, running_applications,
 )
 
-from .Additions.XAWeb import (
+from .additions.XASpeech import (
+    XACommandDetector,
+    XASpeech,
+    XASpeechRecognizer,
+)
+
+from .additions.XALearn import (
+    XALSM,
+)
+
+from .additions.XAUtils import (
+    SDEFParser,
+    XAMenuBar,
+)
+
+from .additions.XAWeb import (
     RSSFeed,
 )
\ No newline at end of file
