@@ -4,7 +4,7 @@ Control the macOS Console application using JXA-like syntax.
 """
 
 from enum import Enum
-from typing import List, Tuple, Union
+from typing import Self
 from AppKit import NSFileManager, NSURL
 
 from PyXA import XABase
@@ -17,6 +17,15 @@ class XAConsoleApplication(XABaseScriptable.XASBApplication):
 
     .. versionadded:: 0.0.5
     """
-    def select_device(self, uuid: str) -> 'XAConsoleApplication':
+    def select_device(self, uuid: str) -> Self:
+        """Select a device.
+
+        :param uuid: The UUID of the device to select
+        :type uuid: str
+        :return: The application ject
+        :rtype: Self
+
+        .. versionadded:: 0.0.5
+        """
         self.xa_scel.selectDevice_(uuid)
         return self
\ No newline at end of file
