@@ -27,16 +27,12 @@ class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XAS
         super().__init__(properties)
         self.xa_wcls = XASafariWindow
 
-        self.frontmost: bool #: Whether Safari is the active application
-        self.name: str #: The name of the application
-        self.version: str #: The version of Safari.app
-        self.current_document: XASafariDocument #: The currently displayed document in the active tab
-        self.current_tab: XASafariTab #: The currently active tab
-
         logging.debug("Initialized XASafariApplication")
 
     @property
     def frontmost(self) -> bool:
+        """Whether Safari is the active application.
+        """
         return self.xa_scel.frontmost()
 
     @frontmost.setter
@@ -45,23 +41,26 @@ class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XAS
 
     @property
     def name(self) -> str:
+        """The name of the application.
+        """
         return self.xa_scel.name()
 
     @property
     def version(self) -> str:
+        """The version of Safari.app.
+        """
         return self.xa_scel.version()
 
     @property
     def current_document(self) -> 'XASafariDocument':
+        """The currently displayed document in the active tab.
+        """
         return self._new_element(self.xa_scel.documents()[0], XASafariDocument)
 
-    @current_document.setter
-    def current_document(self, current_document: 'XASafariDocument'):
-        self.activate()
-        self.front_window.document = current_document
-
     @property
     def current_tab(self) -> 'XASafariTab':
+        """The currently active tab.
+        """
         return self.front_window.current_tab
 
     @current_tab.setter
@@ -306,98 +305,17 @@ class XASafariWindow(XABaseScriptable.XASBWindow, XABaseScriptable.XASBPrintable
     """
     def __init__(self, properties):
         super().__init__(properties)
-        self.name: str #: The title of the window
-        self.id: int #: The unique identifier for the window
-        self.index: int #: The index of the window in the front-to-back ordering
-        self.bounds: tuple[int, int, int, int] #: The bounding rectangle of the window
-        self.closeable: bool #: Whether the window has a close button
-        self.miniaturizable: bool #: Whether the window can be minimized
-        self.miniaturized: bool #: Whether the window is currently minimized
-        self.resizable: bool #: Whether the window can be resized
-        self.visible: bool #: Whether the window is currently visible
-        self.zoomable: bool #: Whether the window can be zoomed
-        self.zoomed: bool #: Whether the window is currently zoomed
-        self.document: XASafariDocument #: The document currently displayed in the window
-        self.current_tab: XASafariTab #: The currently selected tab
-
-    @property
-    def name(self) -> str:
-        return self.xa_elem.name()
-
-    @property
-    def id(self) -> int:
-        return self.xa_elem.id()
-
-    @property
-    def index(self) -> int:
-        return self.xa_elem.index()
-
-    @index.setter
-    def index(self, index: int):
-        self.set_property("index", index)
-
-    @property
-    def bounds(self) -> tuple[int, int, int, int]:
-        rect = self.xa_elem.bounds()
-        origin = rect.origin
-        size = rect.size
-        return (origin.x, origin.y, size.width, size.height)
-
-    @bounds.setter
-    def bounds(self, bounds: tuple[int, int, int, int]):
-        x = bounds[0]
-        y = bounds[1]
-        w = bounds[2]
-        h = bounds[3]
-        value = AppKit.NSValue.valueWithRect_(AppKit.NSMakeRect(x, y, w, h))
-        self.set_property("bounds", value)
-
-    @property
-    def closeable(self) -> bool:
-        return self.xa_elem.closeable()
-
-    @property
-    def miniaturizable(self) -> bool:
-        return self.xa_elem.miniaturizable()
-
-    @property
-    def miniaturized(self) -> bool:
-        return self.xa_elem.miniaturized()
-
-    @miniaturized.setter
-    def miniaturized(self, miniaturized: bool):
-        self.set_property("miniaturized", miniaturized)
-
-    @property
-    def resizable(self) -> bool:
-        return self.xa_elem.resizable()
-
-    @property
-    def visible(self) -> bool:
-        return self.xa_elem.visible()
-
-    @visible.setter
-    def visible(self, visible: bool):
-        self.set_property("visible", visible)
-
-    @property
-    def zoomable(self) -> bool:
-        return self.xa_elem.zoomable()
-
-    @property
-    def zoomed(self) -> bool:
-        return self.xa_elem.zoomed()
-
-    @zoomed.setter
-    def zoomed(self, zoomed: bool):
-        self.set_property("zoomed", zoomed)
 
     @property
     def document(self) -> 'XASafariDocument':
+        """The document currently displayed in the window.
+        """
         return self._new_element(self.xa_elem.document(), XASafariDocument)
 
     @property
     def current_tab(self) -> 'XASafariTab':
+        """The currently selected tab.
+        """
         return self._new_element(self.xa_elem.currentTab(), XASafariTab)
 
     @current_tab.setter
@@ -543,7 +461,7 @@ class XASafariDocumentList(XABase.XAList, XAClipboardCodable):
         
         .. versionadded:: 0.0.4
         """
-        return list(self.xa_elem.arrayByApplyingSelector_("source"))
+        return [x.source() for x in self.xa_elem]
 
     def url(self) -> list[XABase.XAURL]:
         """Gets the file URL of each document in the list.
@@ -564,7 +482,7 @@ class XASafariDocumentList(XABase.XAList, XAClipboardCodable):
         
         .. versionadded:: 0.0.4
         """
-        ls = self.xa_elem.arrayByApplyingSelector_("text")
+        ls = [x.text() for x in self.xa_elem]
         return [XABase.XAText(x) for x in ls]
 
     def by_name(self, name: str) -> Union['XASafariDocument', None]:
@@ -605,7 +523,9 @@ class XASafariDocumentList(XABase.XAList, XAClipboardCodable):
         
         .. versionadded:: 0.0.4
         """
-        return self.by_property("source", source)
+        for doc in self.xa_elem:
+            if doc.source() == source:
+                return self._new_element(doc, XASafariDocument)
 
     def by_url(self, url: XABase.XAURL) -> Union['XASafariDocument', None]:
         """Retrieves the tab whose URL matches the given URL, if one exists.
@@ -723,35 +643,39 @@ class XASafariDocument(XASafariGeneric, XAClipboardCodable, XABaseScriptable.XAS
     """
     def __init__(self, properties):
         super().__init__(properties)
-        self.name: str #: The title of the document
-        self.modified: bool #: Whether the document has been modified since its last save
-        self.file: Union[XABase.XAPath, None] #: The location of the document on the disk, if there is one
-        self.source: str #: The HTML source of the web page currently loaded in the document
-        self.url: XABase.XAURL #: The current URL of the document
-        self.text: XABase.XAText #: The text of the web page currently loaded in the document
 
         logging.debug("Initialized XASafariDocument")
 
     @property
     def name(self) -> str:
+        """The title of the document.
+        """
         return self.xa_elem.name()
 
     @property
     def modified(self) -> bool:
+        """Whether the document has been modified since its last save.
+        """
         return self.xa_elem.modified()
 
     @property
     def file(self) -> str:
+        """The location of the document on the disk, if there is one.
+        """
         file = self.xa_elem.file()
         if file is not None:
             return XABase.XAPath(file)
 
     @property
     def source(self) -> str:
+        """The HTML source of the web page currently loaded in the document.
+        """
         return self.xa_elem.source()
 
     @property
     def url(self) -> XABase.XAURL:
+        """The current URL of the document.
+        """
         return XABase.XAURL(self.xa_elem.URL())
 
     @url.setter
@@ -762,6 +686,8 @@ class XASafariDocument(XASafariGeneric, XAClipboardCodable, XABaseScriptable.XAS
 
     @property
     def text(self) -> XABase.XAText:
+        """The text of the web page currently loaded in the document.
+        """
         return self._new_element(self.xa_elem.text(), XABase.XAText)
 
     def print(self, properties: dict = None, show_dialog: bool = True):
@@ -1078,21 +1004,19 @@ class XASafariTab(XASafariGeneric, XAClipboardCodable):
     """
     def __init__(self, properties):
         super().__init__(properties)
-        self.source: str #: The HTML source of the web page currently loaded in the tab
-        self.url: XABase.XAURL #: The current URL of the tab
-        self.index: int #: The index of the tab, ordered left to right
-        self.text: XABase.XAText #: The text of the web page currently loaded in the tab
-        self.visible: bool #: Whether the tab is currently visible
-        self.name: str #: The title of the tab
 
         logging.debug("Initialized XASafariTab")
 
     @property
     def source(self) -> str:
+        """The HTML source of the web page currently loaded in the tab.
+        """
         return self.xa_elem.source()
 
     @property
     def url(self) -> XABase.XAURL:
+        """The current URL of the tab.
+        """
         return XABase.XAURL(self.xa_elem.URL())
 
     @url.setter
@@ -1103,18 +1027,26 @@ class XASafariTab(XASafariGeneric, XAClipboardCodable):
 
     @property
     def index(self) -> int:
+        """The index of the tab, ordered left to right.
+        """
         return self.xa_elem.index()
 
     @property
     def text(self) -> XABase.XAText:
+        """The text of the web page currently loaded in the tab.
+        """
         return self._new_element(self.xa_elem.text(), XABase.XAText)
 
     @property
     def visible(self) -> bool:
+        """Whether the tab is currently visible.
+        """
         return self.xa_elem.visible()
 
     @property
     def name(self) -> str:
+        """The title of the tab.
+        """
         return self.xa_elem.name()
 
     def move_to(self, window: 'XASafariWindow') -> Self:
