@@ -17,18 +17,17 @@ class XAShortcutsApplication(XABaseScriptable.XASBApplication, XACanOpenPath):
     """
     def __init__(self, properties):
         super().__init__(properties)
-        self.xa_wcls = XAShortcutsWindow
-        
-        self.name: str #: The name of the application
-        self.frontmost: bool #: Whether Shortcuts is the active application
-        self.version: str #: The version number of Shortcuts.app
 
     @property
     def name(self) -> str:
+        """The name of the application.
+        """
         return self.xa_scel.name()
 
     @property
     def frontmost(self) -> bool:
+        """Whether Shortcuts is the active application.
+        """
         return self.xa_scel.frontmost()
 
     @frontmost.setter
@@ -37,6 +36,8 @@ class XAShortcutsApplication(XABaseScriptable.XASBApplication, XACanOpenPath):
 
     @property
     def version(self) -> str:
+        """The version number of Shortcuts.app.
+        """
         return self.xa_scel.version()
 
     def run(self, shortcut: 'XAShortcut', input: Any = None) -> Any:
@@ -101,103 +102,6 @@ class XAShortcutsApplication(XABaseScriptable.XASBApplication, XACanOpenPath):
 
 
 
-class XAShortcutsWindow(XABaseScriptable.XASBWindow):
-    """A window of Shortcuts.app.
-
-    .. seealso:: :class:`XAShortcutsApplication`
-
-    .. versionadded:: 0.1.0
-    """
-    def __init__(self, properties):
-        super().__init__(properties)
-
-        self.name: str #: The title of the window
-        self.id: int #: The unique identifier for the window
-        self.index: int #: The index of the window in the front-to-back ordering
-        self.bounds: tuple[int, int, int, int] #: The bounding rectangle of the window
-        self.closeable: bool #: Whether the window has a close button
-        self.miniaturizable: bool #: Whether the window can be minimized
-        self.miniaturized: bool #: Whether the window is currently minimized
-        self.resizable: bool #: Whether the window can be resized
-        self.visible: bool #: Whether the window is currently visible
-        self.zoomable: bool #: Whether the window can be zoomed
-        self.zoomed: bool #: Whether the window is currently zoomed
-
-    @property
-    def name(self) -> str:
-        return self.xa_elem.name()
-
-    @property
-    def id(self) -> int:
-        return self.xa_elem.id()
-
-    @property
-    def index(self) -> int:
-        return self.xa_elem.index()
-
-    @index.setter
-    def index(self, index: int):
-        self.set_property("index", index)
-
-    @property
-    def bounds(self) -> tuple[int, int, int, int]:
-        rect = self.xa_elem.bounds()
-        origin = rect.origin
-        size = rect.size
-        return (origin.x, origin.y, size.width, size.height)
-
-    @bounds.setter
-    def bounds(self, bounds: tuple[int, int, int, int]):
-        x = bounds[0]
-        y = bounds[1]
-        w = bounds[2]
-        h = bounds[3]
-        value = AppKit.NSValue.valueWithRect_(AppKit.NSMakeRect(x, y, w, h))
-        self.set_property("bounds", value)
-
-    @property
-    def closeable(self) -> bool:
-        return self.xa_elem.closeable()
-
-    @property
-    def miniaturizable(self) -> bool:
-        return self.xa_elem.miniaturizable()
-
-    @property
-    def miniaturized(self) -> bool:
-        return self.xa_elem.miniaturized()
-
-    @miniaturized.setter
-    def miniaturized(self, miniaturized: bool):
-        self.set_property("miniaturized", miniaturized)
-
-    @property
-    def resizable(self) -> bool:
-        return self.xa_elem.resizable()
-
-    @property
-    def visible(self) -> bool:
-        return self.xa_elem.visible()
-
-    @visible.setter
-    def visible(self, visible: bool):
-        self.set_property("visible", visible)
-
-    @property
-    def zoomable(self) -> bool:
-        return self.xa_elem.zoomable()
-
-    @property
-    def zoomed(self) -> bool:
-        return self.xa_elem.zoomed()
-
-    @zoomed.setter
-    def zoomed(self, zoomed: bool):
-        self.set_property("zoomed", zoomed)
-
-
-
-
 class XAShortcutFolderList(XABase.XAList, XAClipboardCodable):
     """A wrapper around lists of shortcuts folders that employs fast enumeration techniques.
 
@@ -284,15 +188,16 @@ class XAShortcutFolder(XABase.XAObject, XAClipboardCodable):
     def __init__(self, properties):
         super().__init__(properties)
 
-        self.id: str #: A unique identifier for the folder
-        self.name: str #: The name string for the folder
-
     @property
     def id(self) -> str:
+        """A unique identifier for the folder.
+        """
         return self.xa_elem.id()
 
     @property
     def name(self) -> str:
+        """The name string for the folder.
+        """
         return self.xa_elem.name()
 
     def shortcuts(self, filter: dict = None) -> 'XAShortcutList':
@@ -551,45 +456,53 @@ class XAShortcut(XABaseScriptable.XASBPrintable, XAClipboardCodable):
     """
     def __init__(self, properties):
         super().__init__(properties)
-        self.id: str #: The unique identifier for the shortcut
-        self.name: str #: The name of the shortcut
-        self.subtitle: str #: The shortcut's subtitle
-        self.folder: XAShortcutFolder #: The folder that contains the shortcut
-        self.color: XABase.XAColor #: The color of the short
-        self.icon: XABase.XAImage #: The shortcut's icon
-        self.accepts_input: bool #: Whether the shortcut accepts input data
-        self.action_count: int #: The number of actions in the shortcut
 
     @property
     def id(self) -> str:
+        """The unique identifier for the shortcut.
+        """
         return self.xa_elem.id()
 
     @property
     def name(self) -> str:
+        """The name of the shortcut.
+        """
         return self.xa_elem.name()
 
     @property
     def subtitle(self) -> str:
+        """The shortcut's subtitle.
+        """
         return self.xa_elem.subtitle()
 
     @property
     def folder(self) -> XAShortcutFolder:
+        """The folder that contains the shortcut.
+        """
         return self._new_element(self.xa_elem.folder(), XAShortcutFolder)
 
     @property
     def color(self) -> XABase.XAColor:
+        """The color of the short.
+        """
         return XABase.XAColor(self.xa_elem.color())
 
     @property
     def icon(self) -> XABase.XAImage:
+        """The shortcut's icon.
+        """
         return XABase.XAImage(self.xa_elem.icon())
 
     @property
     def accepts_input(self) -> bool:
+        """Whether the shortcut accepts input data.
+        """
         return self.xa_elem.acceptsInput()
 
     @property
     def action_count(self) -> int:
+        """The number of actions in the shortcut.
+        """
         return self.xa_elem.actionCount()
 
     def run(self, input: Any = None) -> Any:
